jQuery(document).ready(function ($) {
  // Cache for conversation data with version tracking
  const CACHE_VERSION = "1.0.1"; // Increment this when making style changes
  const conversationCache = new Map();
  let currentConversationId = null;

  // Clear cache if version mismatch
  const savedVersion = localStorage.getItem("hai_cache_version");
  if (savedVersion !== CACHE_VERSION) {
    conversationCache.clear();
    localStorage.setItem("hai_cache_version", CACHE_VERSION);
  }

  // Color input sync
  $("#hai_theme_color").on("input", function () {
    $("#hai_theme_color_text").val($(this).val());
  });

  // API key validation
  $("#hai-validate-api-key").on("click", function () {
    const button = $(this);
    const statusDiv = $("#api-key-status");
    const apiKey = $("#hai_openai_api_key").val();
    const apiKeyContainer = button.closest(".hai-p-6");
    const originalHtml = button.html();

    if (!apiKey) {
      showApiKeyError(statusDiv, apiKeyContainer, haiAdmin.i18n.enterApiKey);
      return;
    }

    // Check if the API key format is valid
    if (!apiKey.match(/^sk-[a-zA-Z0-9-_]{32,}$/)) {
      showApiKeyError(statusDiv, apiKeyContainer, haiAdmin.i18n.invalidApiKey);
      return;
    }

    // Show loading state
    button
      .html(
        `
      <svg class="hai-animate-spin hai-h-4 hai-w-4 hai-text-white" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
        <circle class="hai-opacity-25" cx="12" cy="12" r="10" stroke="currentColor" stroke-width="4"></circle>
        <path class="hai-opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
      </svg>
      <span class="hai-ml-2">${haiAdmin.i18n.validating}</span>
    `
      )
      .prop("disabled", true);
    statusDiv.html("");

    // Make AJAX request to validate API key
    $.ajax({
      url: ajaxurl,
      type: "POST",
      data: {
        action: "hai_validate_api_key",
        nonce: haiAdmin.nonce,
        api_key: apiKey,
      },
      success: function (response) {
        if (response.success) {
          showApiKeySuccess(statusDiv, apiKeyContainer, response.data.message);
        } else {
          showApiKeyError(statusDiv, apiKeyContainer, response.data.message);
        }
      },
      error: function () {
        showApiKeyError(
          statusDiv,
          apiKeyContainer,
          haiAdmin.i18n.validationError
        );
      },
      complete: function () {
        button.html(originalHtml).prop("disabled", false);
      },
    });
  });

  // Handle prompt generation
  $("#hai-generate-prompt").on("click", function () {
    const button = $(this);
    const textarea = $("#hai_custom_prompt");
    const statusDiv = $("#hai-prompt-status");
    const statusIcon = statusDiv.find("svg");
    const statusText = statusDiv.find("p");
    const originalHtml = button.html();

    // Show loading state
    button
      .html(
        `
      <svg class="hai-animate-spin hai-h-4 hai-w-4 hai-text-white" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
        <circle class="hai-opacity-25" cx="12" cy="12" r="10" stroke="currentColor" stroke-width="4"></circle>
        <path class="hai-opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
      </svg>
      <span class="hai-ml-2">${haiAdmin.i18n.analyzingContent}</span>
    `
      )
      .prop("disabled", true);

    // Show initial status
    statusIcon
      .html(
        `
      <circle class="hai-opacity-25" cx="12" cy="12" r="10" stroke="currentColor" stroke-width="4"></circle>
      <path class="hai-opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
    `
      )
      .addClass("hai-animate-spin");
    statusText.text(haiAdmin.i18n.gatheringInfo);
    statusDiv
      .removeClass("hai-hidden hai-bg-green-50 hai-bg-red-50")
      .addClass("hai-bg-blue-50 hai-text-blue-700");

    // Make AJAX request to generate prompt
    $.ajax({
      url: ajaxurl,
      type: "POST",
      data: {
        action: "hai_generate_prompt",
        nonce: haiAdmin.nonce,
      },
      success: function (response) {
        if (response.success) {
          textarea.val(response.data.prompt);
          showPromptSuccess(
            statusIcon,
            statusText,
            statusDiv,
            response.data.message
          );

          // Scroll the textarea to show the beginning
          textarea.scrollTop(0);

          // Highlight the textarea briefly
          textarea.addClass("hai-ring-2 hai-ring-green-500");
          setTimeout(
            () => textarea.removeClass("hai-ring-2 hai-ring-green-500"),
            2000
          );
        } else {
          showPromptError(
            statusIcon,
            statusText,
            statusDiv,
            response.data.message
          );
        }
      },
      error: function () {
        showPromptError(
          statusIcon,
          statusText,
          statusDiv,
          haiAdmin.i18n.promptError
        );
      },
      complete: function () {
        button.html(originalHtml).prop("disabled", false);

        // Hide status after 5 seconds on success
        if (statusDiv.hasClass("hai-bg-green-50")) {
          setTimeout(() => statusDiv.addClass("hai-hidden"), 5000);
        }
      },
    });
  });

  // Helper functions for API key validation
  function showApiKeyError(statusDiv, container, message) {
    statusDiv.html(`
      <div class="hai-flex hai-items-center hai-text-red-600">
        <svg class="hai-w-4 hai-h-4 hai-mr-1.5" fill="none" stroke="currentColor" viewBox="0 0 24 24">
          <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M12 8v4m0 4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z"></path>
        </svg>
        ${message}
      </div>
    `);
    container
      .removeClass("hai-bg-green-50 hai-border-green-100")
      .addClass("hai-bg-red-50 hai-border-red-100");
    updateApiKeyStatus(container, false);
  }

  function showApiKeySuccess(statusDiv, container, message) {
    statusDiv.html(`
      <div class="hai-flex hai-items-center hai-text-green-600">
        <svg class="hai-w-4 hai-h-4 hai-mr-1.5" fill="none" stroke="currentColor" viewBox="0 0 24 24">
          <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M5 13l4 4L19 7"></path>
        </svg>
        ${message}
      </div>
    `);
    container
      .removeClass("hai-bg-red-50 hai-border-red-100")
      .addClass("hai-bg-green-50 hai-border-green-100");
    updateApiKeyStatus(container, true);
  }

  function updateApiKeyStatus(container, isValid) {
    const badge = container.find(".hai-rounded-lg.hai-text-xs");
    const asterisk = container.find(
      ".hai-text-" + (isValid ? "red" : "green") + "-600"
    );

    badge
      .removeClass(
        "hai-bg-" +
          (isValid ? "red" : "green") +
          "-100 hai-text-" +
          (isValid ? "red" : "green") +
          "-800"
      )
      .addClass(
        "hai-bg-" +
          (isValid ? "green" : "red") +
          "-100 hai-text-" +
          (isValid ? "green" : "red") +
          "-800"
      );
    badge.text(isValid ? haiAdmin.i18n.configured : haiAdmin.i18n.required);

    asterisk
      .removeClass("hai-text-" + (isValid ? "red" : "green") + "-600")
      .addClass("hai-text-" + (isValid ? "green" : "red") + "-600");
  }

  // Helper functions for prompt generation
  function showPromptSuccess(icon, text, div, message) {
    icon
      .html(
        `
      <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M5 13l4 4L19 7"></path>
    `
      )
      .removeClass("hai-animate-spin");
    text.text(message);
    div
      .removeClass(
        "hai-bg-blue-50 hai-bg-red-50 hai-text-blue-700 hai-text-red-700"
      )
      .addClass("hai-bg-green-50 hai-text-green-700");
  }

  function showPromptError(icon, text, div, message) {
    icon
      .html(
        `
      <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M12 8v4m0 4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z"></path>
    `
      )
      .removeClass("hai-animate-spin");
    text.text(message);
    div
      .removeClass(
        "hai-bg-blue-50 hai-bg-green-50 hai-text-blue-700 hai-text-green-700"
      )
      .addClass("hai-bg-red-50 hai-text-red-700");
  }

  // Status filter
  $("#hai-status-filter").on("change", function () {
    const status = $(this).val();
    $(".hai-conversation-row").each(function () {
      const row = $(this);
      if (!status || row.data("status") === status) {
        row.show();
      } else {
        row.hide();
      }
    });
  });

  // View conversation
  $(".view-conversation").on("click", function () {
    const conversationId = $(this).data("id");
    openConversationModal(conversationId);
  });

  // Close modal and cleanup
  $("#hai-close-modal").on("click", function () {
    const modal = $("#hai-conversation-modal");
    modal.addClass("hai-hidden");
    // Clear current conversation ID
    currentConversationId = null;
    // Clear modal content
    $("#hai-conversation-content").empty();
    // Reset conversation details
    $(".hai-conversation-name").empty();
    $(".hai-conversation-meta").empty();
    $(".hai-conversation-ip").empty();
    $(".hai-conversation-time").empty();
    $(".hai-conversation-location .hai-location-content").empty();
  });

  // Delete conversation with confirmation
  $(".delete-conversation").on("click", async function () {
    const button = $(this);
    const conversationId = button.data("id");
    const row = button.closest("tr");

    try {
      const confirmed = await showConfirmDialog(
        "Are you sure you want to delete this conversation?"
      );
      if (!confirmed) return;

      const response = await $.ajax({
        url: ajaxurl,
        type: "POST",
        data: {
          action: "hai_delete_conversation",
          nonce: haiAdmin.nonce,
          conversation_id: conversationId,
        },
      });

      if (response.success) {
        row.fadeOut(() => {
          row.remove();
          // Clear cache for this conversation
          conversationCache.delete(conversationId);
        });
      } else {
        throw new Error(response.data.message);
      }
    } catch (error) {
      showErrorMessage(error.message || "Failed to delete conversation.");
    }
  });

  // Promise-based confirm dialog
  function showConfirmDialog(message) {
    return new Promise((resolve) => {
      resolve(confirm(message));
    });
  }

  // Error message helper
  function showErrorMessage(message) {
    const errorHtml = `
      <div class="hai-fixed hai-top-4 hai-right-4 hai-z-50 hai-bg-red-100 hai-border hai-border-red-400 hai-text-red-700 hai-px-4 hai-py-3 hai-rounded hai-shadow-lg" role="alert">
        <div class="hai-flex">
          <div class="hai-py-1">
            <svg class="hai-w-6 hai-h-6 hai-text-red-500 hai-mr-4" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M12 8v4m0 4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z"></path>
            </svg>
          </div>
          <div>
            <p class="hai-font-bold">Error</p>
            <p class="hai-text-sm">${escapeHtml(message)}</p>
          </div>
        </div>
      </div>
    `;

    const errorElement = $(errorHtml);
    $("body").append(errorElement);
    setTimeout(() => errorElement.fadeOut(() => errorElement.remove()), 5000);
  }

  // Render conversation messages
  function renderConversation(messages) {
    const content = $("#hai-conversation-content");
    content.empty();

    if (!Array.isArray(messages) || messages.length === 0) {
      content.html(`
        <div class="hai-flex hai-flex-col hai-items-center hai-justify-center hai-h-full hai-py-12">
          <svg class="hai-w-16 hai-h-16 hai-text-gray-300" fill="none" stroke="currentColor" viewBox="0 0 24 24">
            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" d="M8 12h.01M12 12h.01M16 12h.01M21 12c0 4.418-4.03 8-9 8a9.863 9.863 0 01-4.255-.949L3 20l1.395-3.72C3.512 15.042 3 13.574 3 12c0-4.418 4.03-8 9-8s9 3.582 9 8z"></path>
          </svg>
          <p class="hai-mt-4 hai-text-sm hai-text-gray-500">No messages found in this conversation.</p>
        </div>
      `);
      return;
    }

    const fragment = document.createDocumentFragment();

    messages.forEach((message) => {
      if (!message?.role || !message?.content) return;

      const isAi = message.role === "assistant";
      const messageElement = $(createMessageHTML(message, isAi));
      fragment.appendChild(messageElement[0]);
    });

    content.append(fragment);
    requestAnimationFrame(() => {
      content.animate({ scrollTop: content[0].scrollHeight }, 300);
    });
  }

  // Create message HTML (moved to separate function for better organization)
  function createMessageHTML(message, isAi) {
    const userName = $(".hai-conversation-name").text() || "Anonymous User";
    const messageTime = message.timestamp
      ? `<span class="hai-text-xs hai-text-gray-400">${message.timestamp}</span>`
      : "";

    return `
      <div class="hai-flex hai-items-start hai-space-x-4 hai-mb-6 ${
        isAi ? "" : "hai-flex-row-reverse hai-space-x-reverse"
      }">
        <div class="hai-flex-shrink-0">
          <div class="hai-h-9 hai-w-9 hai-rounded-full hai-flex hai-items-center hai-justify-center hai-overflow-hidden hai-bg-[#d702fc]/10">
            ${
              isAi && haiAdmin.agentAvatar
                ? `<img src="${haiAdmin.agentAvatar}?v=${CACHE_VERSION}" alt="${haiAdmin.botName}" class="hai-w-full hai-h-full hai-object-cover">`
                : `<svg class="hai-h-5 hai-w-5 hai-text-[#d702fc]" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" d="${
                      isAi
                        ? "M9.75 17L9 20l-1 1h8l-1-1-.75-3M3 13h18M5 17h14a2 2 0 002-2V5a2 2 0 00-2-2H5a2 2 0 00-2 2v10a2 2 0 002 2z"
                        : "M16 7a4 4 0 11-8 0 4 4 0 018 0zM12 14a7 7 0 00-7 7h14a7 7 0 00-7-7z"
                    }"></path>
                  </svg>`
            }
          </div>
        </div>
        <div class="hai-flex hai-flex-col hai-flex-1 ${
          isAi ? "" : "hai-items-end"
        }">
          <div class="hai-flex hai-items-center hai-space-x-2 hai-mb-1.5 ${
            isAi ? "" : "hai-flex-row-reverse hai-space-x-reverse"
          }">
            <span class="hai-text-sm hai-font-medium hai-text-gray-900">
              ${isAi ? haiAdmin.botName : userName}
            </span>
            ${messageTime}
          </div>
          <div class="hai-rounded-2xl hai-px-4 hai-py-3 hai-max-w-[85%] ${
            isAi
              ? "hai-bg-gray-100 hai-text-gray-900"
              : "hai-bg-[#d702fc] hai-text-white"
          } hai-shadow-sm">
            <div class="hai-text-sm hai-leading-relaxed hai-whitespace-pre-wrap">${escapeHtml(
              message.content
            )}</div>
          </div>
        </div>
      </div>
    `;
  }

  // Update conversation details in modal
  function updateConversationDetails(data) {
    // Clear existing content first
    $(".hai-conversation-name").empty();
    $(".hai-conversation-meta").empty();
    $(".hai-conversation-ip").empty();
    $(".hai-conversation-time").empty();

    // Update with new content
    $(".hai-conversation-name").text(data.user_name || "Anonymous User");
    $(".hai-conversation-meta").text(parseUserAgent(data.user_agent || ""));
    $(".hai-conversation-ip").text(data.user_ip || "Unknown IP");
    $(".hai-conversation-time").text(data.created_at || "");
    updateLocationInfo(data.location);
  }

  // Update location information
  function updateLocationInfo(locationData) {
    const locationDiv = $(".hai-conversation-location .hai-location-content");
    locationDiv.empty();

    try {
      const location =
        typeof locationData === "string"
          ? JSON.parse(locationData)
          : locationData;

      if (location?.city || location?.country) {
        const locationHtml = `
          <div class="hai-flex hai-items-center hai-space-x-2">
            ${
              location.country_code
                ? `<div class="hai-flex-shrink-0 hai-w-6 hai-h-4 hai-relative hai-rounded-sm hai-overflow-hidden hai-border hai-border-gray-200">
                    <img src="${
                      haiAdmin.pluginUrl
                    }assets/images/flags/${location.country_code.toLowerCase()}.svg?v=${CACHE_VERSION}"
                      alt="${location.country || ""}"
                      class="hai-w-full hai-h-full hai-object-cover"
                      onerror="this.parentElement.style.display='none'">
                  </div>`
                : ""
            }
            <span class="hai-text-sm hai-text-gray-700">
              ${
                [location.city, location.country].filter(Boolean).join(", ") ||
                "Unknown Location"
              }
            </span>
          </div>
        `;
        locationDiv.html(locationHtml);
      } else {
        locationDiv.html(
          '<span class="hai-text-sm hai-text-gray-700">Unknown Location</span>'
        );
      }
    } catch (e) {
      locationDiv.html(
        '<span class="hai-text-sm hai-text-gray-700">Unknown Location</span>'
      );
    }
  }

  // Open conversation modal with optimized data fetching
  async function openConversationModal(conversationId) {
    // Don't proceed if we're already viewing this conversation
    if (currentConversationId === conversationId) return;

    const modal = $("#hai-conversation-modal");
    const content = $("#hai-conversation-content");

    try {
      // Reset modal state
      modal.removeClass("hai-hidden");
      content.empty();
      currentConversationId = conversationId;

      // Show loading state
      content.html(`
        <div class="hai-flex hai-items-center hai-justify-center hai-h-full">
          <div class="hai-flex hai-flex-col hai-items-center hai-gap-4">
            <div class="hai-w-12 hai-h-12 hai-border-4 hai-border-[#d702fc] hai-border-t-transparent hai-rounded-full hai-animate-spin"></div>
            <p class="hai-text-gray-600 hai-font-medium">Loading conversation...</p>
          </div>
        </div>
      `);

      // Always fetch fresh data and update cache
      const response = await $.ajax({
        url: ajaxurl,
        type: "POST",
        data: {
          action: "hai_get_conversation",
          nonce: haiAdmin.nonce,
          conversation_id: conversationId,
        },
      });

      if (!response.success) {
        throw new Error(
          response.data?.message || "Failed to load conversation"
        );
      }

      const conversationData = response.data;

      // Update cache with fresh data
      const cacheKey = `${conversationId}_${CACHE_VERSION}`;
      conversationCache.set(cacheKey, conversationData);

      // Update UI with conversation data
      updateConversationDetails(conversationData);
      renderConversation(conversationData.messages);

      // Update row status in the table if needed
      const row = $(`.hai-conversation-row[data-id="${conversationId}"]`);
      if (row.length && row.data("status") === "unread") {
        row.data("status", "read");
        row
          .find(".hai-status-badge")
          .removeClass("hai-bg-blue-100 hai-text-blue-800")
          .addClass("hai-bg-gray-100 hai-text-gray-800")
          .text("Read");
      }
    } catch (error) {
      showErrorMessage(error.message);
      content.html(`
        <div class="hai-flex hai-flex-col hai-items-center hai-justify-center hai-h-full hai-p-8">
          <svg class="hai-w-16 hai-h-16 hai-text-red-500 hai-mb-4" fill="none" stroke="currentColor" viewBox="0 0 24 24">
            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" d="M12 8v4m0 4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z"></path>
          </svg>
          <p class="hai-text-gray-600 hai-text-center">${escapeHtml(
            error.message
          )}</p>
          <button onclick="location.reload()" class="hai-mt-4 hai-px-4 hai-py-2 hai-bg-[#d702fc] hai-text-white hai-rounded-lg hai-shadow-sm hover:hai-bg-[#b502d6] hai-transition-colors">
            Reload Page
          </button>
        </div>
      `);
    }
  }

  // Helper function to escape HTML
  function escapeHtml(unsafe) {
    return unsafe
      .replace(/&/g, "&amp;")
      .replace(/</g, "&lt;")
      .replace(/>/g, "&gt;")
      .replace(/"/g, "&quot;")
      .replace(/'/g, "&#039;");
  }

  // Parse user agent to get OS and browser
  function parseUserAgent(userAgent) {
    if (!userAgent) return "Unknown Device";

    let os = "Unknown OS";
    let browser = "Unknown Browser";

    // Detect OS
    if (userAgent.includes("Windows")) os = "Windows";
    else if (userAgent.includes("Mac OS X")) os = "macOS";
    else if (userAgent.includes("Linux")) os = "Linux";
    else if (userAgent.includes("iOS")) os = "iOS";
    else if (userAgent.includes("Android")) os = "Android";

    // Detect Browser
    if (userAgent.includes("Chrome") && !userAgent.includes("Chromium"))
      browser = "Chrome";
    else if (userAgent.includes("Firefox")) browser = "Firefox";
    else if (userAgent.includes("Safari") && !userAgent.includes("Chrome"))
      browser = "Safari";
    else if (userAgent.includes("Edge")) browser = "Edge";
    else if (userAgent.includes("Opera")) browser = "Opera";

    return `${os} · ${browser}`;
  }
});
