jQuery(document).ready(function ($) {
  const chatButton = $("#hai-chat-button");
  const chatWindow = $("#hai-chat-window");
  const closeChat = $("#hai-close-chat");
  const messagesContainer = $("#hai-messages");
  const chatForm = $("#hai-chat-form");
  const messageInput = $("#hai-message-input");
  const sessionInput = $("#hai-session-id");

  let sessionTimeout;
  const SESSION_TIMEOUT = 5 * 60 * 1000; // 5 minutes in milliseconds

  // Function to clear session
  function clearSession() {
    sessionInput.val("");
    messagesContainer.find(".hai-message-user, .hai-message-ai").remove();
    // Keep the welcome message
    if (messagesContainer.children().length === 0) {
      appendWelcomeMessage();
    }
  }

  // Function to reset session timeout
  function resetSessionTimeout() {
    clearTimeout(sessionTimeout);
    sessionTimeout = setTimeout(clearSession, SESSION_TIMEOUT);
  }

  // Function to append welcome message
  function appendWelcomeMessage() {
    const welcomeHtml = `
      <div class="hai-flex hai-items-end hai-space-x-2">
        <div class="hai-flex-shrink-0">
          <div class="hai-w-8 hai-h-8 hai-rounded-full hai-flex hai-items-center hai-justify-center hai-text-white hai-shadow-sm hai-overflow-hidden" style="background-color: ${
            haiChat.themeColor
          }">
            ${
              haiChat.agentAvatar
                ? `<img src="${haiChat.agentAvatar}?v=${Date.now()}" alt="${
                    haiChat.botName
                  }" class="hai-w-full hai-h-full hai-object-cover">`
                : `<svg class="hai-w-5 hai-h-5" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                  <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M9.75 17L9 20l-1 1h8l-1-1-.75-3M3 13h18M5 17h14a2 2 0 002-2V5a2 2 0 00-2-2H5a2 2 0 00-2 2v10a2 2 0 002 2z"></path>
                </svg>`
            }
          </div>
        </div>
        <div class="hai-group">
          <div class="hai-rounded-2xl hai-px-4 hai-py-2 hai-max-w-[85%] hai-bg-gray-100 hai-shadow-sm">
            <p class="hai-text-sm hai-text-gray-800">
              ${
                haiChat.welcomeMessage ||
                (haiChat.userName
                  ? `Hello ${haiChat.userName}! How can I help you today?`
                  : "Hello! How can I help you today?")
              }
            </p>
          </div>
          <div class="hai-mt-1 hai-text-xs hai-text-gray-400 hai-px-2">
            ${new Date().toLocaleTimeString([], {
              hour: "2-digit",
              minute: "2-digit",
            })}
          </div>
        </div>
      </div>
    `;
    messagesContainer.html(welcomeHtml);
  }

  // Toggle chat window
  chatButton.on("click", function () {
    chatWindow.toggleClass("hai-hidden");
    if (!chatWindow.hasClass("hai-hidden")) {
      messageInput.focus();
      resetSessionTimeout();
    }
  });

  closeChat.on("click", function () {
    chatWindow.addClass("hai-hidden");
    clearSession();
  });

  // Handle rate limit exceeded error
  function handleRateLimitError(message) {
    const errorHtml = `
      <div class="hai-flex hai-items-center hai-justify-center hai-p-3">
        <div class="hai-bg-red-100 hai-border hai-border-red-400 hai-text-red-700 hai-px-4 hai-py-3 hai-rounded hai-relative" role="alert">
          <span class="hai-block hai-sm:hai-inline">${escapeHtml(
            message
          )}</span>
        </div>
      </div>
    `;
    messagesContainer.append(errorHtml);
    scrollToBottom();
  }

  // Update chat form submission
  chatForm.on("submit", function (e) {
    e.preventDefault();

    const message = messageInput.val().trim();
    if (!message) return;

    // Reset session timeout on new message
    resetSessionTimeout();

    // Add user message to chat
    appendMessage("user", message);
    messageInput.val("").focus();

    // Show typing indicator
    const typingIndicator = appendTypingIndicator();

    // Send message to server
    $.ajax({
      url: haiChat.ajaxUrl,
      type: "POST",
      data: {
        action: "hai_send_message",
        nonce: haiChat.nonce,
        message: message,
        session_id: sessionInput.val(),
      },
      success: function (response) {
        // Remove typing indicator
        typingIndicator.remove();

        if (response.success) {
          // Add AI response to chat
          appendMessage("ai", response.data.message);

          // Update session ID if new
          if (response.data.session_id) {
            sessionInput.val(response.data.session_id);
          }

          resetSessionTimeout();
        } else {
          if (response.data.message.includes("rate limit exceeded")) {
            handleRateLimitError(response.data.message);
          } else {
            appendErrorMessage(response.data.message);
          }
        }
      },
      error: function () {
        // Remove typing indicator
        typingIndicator.remove();
        appendErrorMessage("An error occurred. Please try again.");
      },
    });
  });

  // Append a message to the chat
  function appendMessage(type, content) {
    const isAi = type === "ai";
    const messageHtml = `
      <div class="hai-flex hai-items-end hai-space-x-2 hai-mb-4 ${
        isAi ? "" : "hai-flex-row-reverse hai-space-x-reverse"
      } ${isAi ? "hai-message-ai" : "hai-message-user"}">
        <div class="hai-flex-shrink-0">
          <div class="hai-w-8 hai-h-8 hai-rounded-full hai-flex hai-items-center hai-justify-center hai-text-white hai-shadow-sm hai-overflow-hidden" style="background-color: ${
            isAi ? haiChat.themeColor : "#d702fc"
          }">
            ${
              isAi && haiChat.agentAvatar
                ? `<img src="${haiChat.agentAvatar}" alt="${haiChat.botName}" class="hai-w-full hai-h-full hai-object-cover">`
                : `<svg class="hai-w-5 hai-h-5" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="${
                      isAi
                        ? "M9.75 17L9 20l-1 1h8l-1-1-.75-3M3 13h18M5 17h14a2 2 0 002-2V5a2 2 0 00-2-2H5a2 2 0 00-2 2v10a2 2 0 002 2z"
                        : "M16 7a4 4 0 11-8 0 4 4 0 018 0zM12 14a7 7 0 00-7 7h14a7 7 0 00-7-7z"
                    }"></path>
                  </svg>`
            }
          </div>
        </div>
        <div class="hai-group hai-flex hai-flex-col ${
          isAi ? "" : "hai-items-end"
        }">
          <div class="hai-flex hai-flex-col ${isAi ? "" : "hai-items-end"}">
            <div class="hai-rounded-2xl hai-px-4 hai-py-2 hai-shadow-sm ${
              isAi ? "hai-bg-gray-100" : "hai-bg-[#d702fc]"
            }">
              <div class="hai-text-sm hai-leading-relaxed ${
                isAi ? "hai-text-gray-800" : "hai-text-white"
              }">${escapeHtml(content)}</div>
            </div>
          </div>
          <div class="hai-mt-1 hai-text-xs hai-text-gray-400 ${
            isAi ? "hai-pl-2" : "hai-pr-2"
          }">
            ${new Date().toLocaleTimeString([], {
              hour: "2-digit",
              minute: "2-digit",
            })}
          </div>
        </div>
      </div>
    `;

    messagesContainer.append(messageHtml);
    scrollToBottom();
  }

  // Append error message
  function appendErrorMessage(message) {
    const errorHtml = `
            <div class="hai-flex hai-items-center hai-justify-center hai-p-3">
                <div class="hai-bg-red-100 hai-border hai-border-red-400 hai-text-red-700 hai-px-4 hai-py-3 hai-rounded hai-relative" role="alert">
                    <span class="hai-block hai-sm:hai-inline">${escapeHtml(
                      message
                    )}</span>
                </div>
            </div>
        `;

    messagesContainer.append(errorHtml);
    scrollToBottom();
  }

  // Append typing indicator
  function appendTypingIndicator() {
    const indicatorHtml = `
      <div class="hai-flex hai-items-end hai-space-x-2 hai-mb-4">
        <div class="hai-flex-shrink-0">
          <div class="hai-w-8 hai-h-8 hai-rounded-full hai-flex hai-items-center hai-justify-center hai-text-white hai-shadow-sm" style="background-color: ${haiChat.themeColor}">
            <svg class="hai-w-5 hai-h-5" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M9.75 17L9 20l-1 1h8l-1-1-.75-3M3 13h18M5 17h14a2 2 0 002-2V5a2 2 0 00-2-2H5a2 2 0 00-2 2v10a2 2 0 002 2z"></path>
            </svg>
          </div>
        </div>
        <div class="hai-group">
          <div class="hai-rounded-2xl hai-px-4 hai-py-3 hai-bg-gray-100 hai-shadow-sm">
            <div class="hai-flex hai-space-x-2">
              <div class="hai-w-2 hai-h-2 hai-bg-gray-400 hai-rounded-full hai-animate-bounce"></div>
              <div class="hai-w-2 hai-h-2 hai-bg-gray-400 hai-rounded-full hai-animate-bounce" style="animation-delay: 0.2s"></div>
              <div class="hai-w-2 hai-h-2 hai-bg-gray-400 hai-rounded-full hai-animate-bounce" style="animation-delay: 0.4s"></div>
            </div>
          </div>
        </div>
      </div>
    `;

    const indicator = $(indicatorHtml);
    messagesContainer.append(indicator);
    scrollToBottom();
    return indicator;
  }

  // Escape HTML to prevent XSS
  function escapeHtml(unsafe) {
    return unsafe
      .replace(/&/g, "&amp;")
      .replace(/</g, "&lt;")
      .replace(/>/g, "&gt;")
      .replace(/"/g, "&quot;")
      .replace(/'/g, "&#039;");
  }

  // Scroll messages container to bottom
  function scrollToBottom() {
    messagesContainer.scrollTop(messagesContainer[0].scrollHeight);
  }

  // Initialize welcome message
  appendWelcomeMessage();

  // Handle page visibility change
  document.addEventListener("visibilitychange", function () {
    if (document.hidden) {
      // Clear session when page is hidden for more than 5 minutes
      clearTimeout(sessionTimeout);
      sessionTimeout = setTimeout(clearSession, SESSION_TIMEOUT);
    } else {
      // Reset timeout when page becomes visible again
      if (sessionInput.val() && !chatWindow.hasClass("hai-hidden")) {
        resetSessionTimeout();
      }
    }
  });
});
