<?php
if (!defined('ABSPATH')) {
  exit;
}

/**
 * Get plugin settings with defaults
 *
 * @param string $key The setting key to retrieve
 * @return mixed The setting value
 */
function hai_get_setting($key)
{
  $defaults = array(
    'hai_enable_chat' => true,
    'hai_openai_api_key' => '',
    'hai_ai_model' => 'gpt-4',
    'hai_bot_name' => 'Hai AI',
    'hai_theme_color' => '#d702fc',
    'hai_custom_prompt' => 'You are Hai AI, a helpful chatbot assistant.',
    'hai_ipinfo_api_key' => '',
    'hai_agent_avatar' => 'agent1.png'
  );

  $value = get_option($key, $defaults[$key] ?? null);

  // Special handling for boolean values
  if ($key === 'hai_enable_chat') {
    return filter_var($value, FILTER_VALIDATE_BOOLEAN);
  }

  return $value;
}

/**
 * Sanitize and validate settings
 *
 * @param string $key The setting key
 * @param mixed $value The setting value
 * @return mixed The sanitized value
 */
function hai_sanitize_setting($key, $value)
{
  switch ($key) {
    case 'hai_enable_chat':
      return filter_var($value, FILTER_VALIDATE_BOOLEAN);

    case 'hai_theme_color':
      $color = sanitize_hex_color($value);
      return $color ?: '#d702fc';

    case 'hai_openai_api_key':
      $key = sanitize_text_field($value);
      if (empty($key)) {
        return '';
      }
      return $key;

    case 'hai_ai_model':
      $model = sanitize_text_field($value);
      return in_array($model, array('gpt-4', 'gpt-3.5-turbo')) ? $model : 'gpt-4';

    case 'hai_bot_name':
      $name = sanitize_text_field($value);
      return !empty($name) ? $name : 'Hai AI';

    case 'hai_custom_prompt':
      $prompt = sanitize_textarea_field($value);
      return !empty($prompt) ? $prompt : 'You are Hai AI, a helpful chatbot assistant.';

    case 'hai_ipinfo_api_key':
      return sanitize_text_field($value);

    case 'hai_agent_avatar':
      $avatar = sanitize_text_field($value);
      return !empty($avatar) ? $avatar : 'agent1.png';

    default:
      return sanitize_text_field($value);
  }
}

/**
 * Save plugin settings
 *
 * @return bool Whether the settings were saved successfully
 */
function hai_save_settings($settings)
{
  if (!current_user_can('manage_options')) {
    return false;
  }

  $success = true;

  // Handle checkbox separately since it won't be in $_POST when unchecked
  update_option('hai_enable_chat', isset($settings['hai_enable_chat']));

  // Settings to save
  $settings_to_save = array(
    'hai_openai_api_key',
    'hai_ai_model',
    'hai_bot_name',
    'hai_theme_color',
    'hai_custom_prompt',
    'hai_ipinfo_api_key',
    'hai_agent_avatar'
  );

  foreach ($settings_to_save as $key) {
    if (isset($settings[$key])) {
      $value = hai_sanitize_setting($key, $settings[$key]);
      if (!update_option($key, $value)) {
        $success = false;
      }
    }
  }

  return $success;
}

/**
 * Get user location data
 *
 * @param string $ip_address The IP address to look up
 * @return array Location data
 */
function hai_get_location_data($ip_address)
{
  $api_key = hai_get_setting('hai_ipinfo_api_key');
  $url = "https://ipinfo.io/{$ip_address}/json";
  if ($api_key) {
    $url .= "?token={$api_key}";
  }

  $response = wp_remote_get($url);
  if (is_wp_error($response)) {
    return array();
  }

  $data = json_decode(wp_remote_retrieve_body($response), true);
  if (!empty($data)) {
    // IPInfo returns 'country' as the country code and 'country_name' as the full name
    // We'll store both, but rename 'country' to 'country_code' for clarity
    if (isset($data['country'])) {
      $data['country_code'] = strtolower($data['country']);
      // If country_name is not provided (free tier), we'll keep the code as country
      if (!isset($data['country_name'])) {
        $data['country'] = $data['country'];
      } else {
        $data['country'] = $data['country_name'];
      }
    }
  }

  return $data ?: array();
}

/**
 * Render the dashboard page
 */
function hai_render_dashboard()
{
  if (!current_user_can('manage_options')) {
    return;
  }

  $db = new Hai_DB();
  $conversations = $db->get_conversations();
  require_once HAI_SUPPORT_PLUGIN_DIR . 'templates/dashboard.php';
}

/**
 * Render the settings page
 */
function hai_render_settings()
{
  if (!current_user_can('manage_options')) {
    return;
  }

  // Save settings if form is submitted
  if (isset($_POST['hai_settings_nonce']) && wp_verify_nonce($_POST['hai_settings_nonce'], 'hai_save_settings')) {
    $settings = array(
      'hai_openai_api_key',
      'hai_ai_model',
      'hai_bot_name',
      'hai_theme_color',
      'hai_custom_prompt',
      'hai_ipinfo_api_key',
      'hai_agent_avatar'
    );

    // Handle checkbox separately since it won't be in $_POST when unchecked
    update_option('hai_enable_chat', isset($_POST['hai_enable_chat']));

    foreach ($settings as $setting) {
      if (isset($_POST[$setting])) {
        update_option($setting, hai_sanitize_setting($setting, $_POST[$setting]));
      }
    }

    add_settings_error(
      'hai_settings',
      'settings_updated',
      __('Settings saved successfully.', 'hai-support'),
      'updated'
    );
  }

  require_once HAI_SUPPORT_PLUGIN_DIR . 'templates/settings.php';
}

/**
 * Render the AI Scanner page
 */
function hai_render_scanner()
{
  if (!current_user_can('manage_options')) {
    return;
  }

  require_once HAI_SUPPORT_PLUGIN_DIR . 'templates/ai-scanner.php';
}

/**
 * Enqueue and localize chat scripts
 */
function hai_localize_chat_script()
{
  $display_name = '';
  if (is_user_logged_in()) {
    $display_name = wp_get_current_user()->display_name;
    // Extract first name (split by space and take first part)
    $display_name = explode(' ', $display_name)[0];
  }

  wp_localize_script('hai-chat-script', 'haiChat', array(
    'ajaxUrl' => admin_url('admin-ajax.php'),
    'nonce' => wp_create_nonce('hai-chat-nonce'),
    'botName' => hai_get_setting('hai_bot_name'),
    'themeColor' => hai_get_setting('hai_theme_color'),
    'agentAvatar' => hai_get_setting('hai_agent_avatar') ? HAI_SUPPORT_PLUGIN_URL . 'assets/images/avatars/' . hai_get_setting('hai_agent_avatar') : '',
    'userName' => $display_name
  ));
}
add_action('wp_enqueue_scripts', 'hai_localize_chat_script', 20);
