<?php
if (!defined('ABSPATH')) {
  exit;
}

class Hai_Admin
{
  private $db;
  private $api;

  public function __construct()
  {
    $this->db = new Hai_DB();
    $this->api = new Hai_API();

    add_action('admin_init', array($this, 'register_settings'));
    add_action('wp_ajax_hai_validate_api_key', array($this, 'validate_api_key'));
    add_action('wp_ajax_hai_mark_as_read', array($this, 'mark_as_read'));
    add_action('wp_ajax_hai_delete_conversation', array($this, 'delete_conversation'));
    add_action('wp_ajax_hai_get_conversation', array($this, 'get_conversation'));
  }

  public function register_settings()
  {
    register_setting('hai_support_options', 'hai_enable_chat', array(
      'type' => 'boolean',
      'default' => true
    ));

    register_setting('hai_support_options', 'hai_openai_api_key', array(
      'type' => 'string',
      'sanitize_callback' => 'sanitize_text_field'
    ));

    register_setting('hai_support_options', 'hai_ai_model', array(
      'type' => 'string',
      'default' => 'gpt-4',
      'sanitize_callback' => 'sanitize_text_field'
    ));

    register_setting('hai_support_options', 'hai_bot_name', array(
      'type' => 'string',
      'default' => 'Hai AI',
      'sanitize_callback' => 'sanitize_text_field'
    ));

    register_setting('hai_support_options', 'hai_theme_color', array(
      'type' => 'string',
      'default' => '#3498db',
      'sanitize_callback' => 'sanitize_hex_color'
    ));

    register_setting('hai_support_options', 'hai_custom_prompt', array(
      'type' => 'string',
      'default' => 'You are Hai AI, a helpful chatbot assistant.',
      'sanitize_callback' => 'sanitize_textarea_field'
    ));

    register_setting('hai_support_options', 'hai_ipinfo_api_key', array(
      'type' => 'string',
      'sanitize_callback' => 'sanitize_text_field'
    ));
  }

  public function validate_api_key()
  {
    check_ajax_referer('hai-admin-nonce', 'nonce');

    if (!current_user_can('manage_options')) {
      wp_send_json_error(array(
        'message' => __('You do not have permission to perform this action.', 'hai-support')
      ));
    }

    $api_key = sanitize_text_field($_POST['api_key'] ?? '');

    if (empty($api_key)) {
      wp_send_json_error(array(
        'message' => __('API key cannot be empty.', 'hai-support')
      ));
    }

    $is_valid = $this->api->validate_api_key($api_key);

    if ($is_valid) {
      wp_send_json_success(array(
        'message' => __('API key is valid.', 'hai-support')
      ));
    } else {
      wp_send_json_error(array(
        'message' => __('Invalid API key.', 'hai-support')
      ));
    }
  }

  public function mark_as_read()
  {
    check_ajax_referer('hai-admin-nonce', 'nonce');

    if (!current_user_can('manage_options')) {
      wp_send_json_error(array(
        'message' => __('You do not have permission to perform this action.', 'hai-support')
      ));
    }

    $conversation_id = intval($_POST['conversation_id'] ?? 0);

    if (empty($conversation_id)) {
      wp_send_json_error(array(
        'message' => __('Invalid conversation ID.', 'hai-support')
      ));
    }

    $result = $this->db->update_conversation($conversation_id, array(
      'status' => 'read'
    ));

    if ($result) {
      wp_send_json_success(array(
        'message' => __('Conversation marked as read.', 'hai-support')
      ));
    } else {
      wp_send_json_error(array(
        'message' => __('Failed to update conversation.', 'hai-support')
      ));
    }
  }

  public function delete_conversation()
  {
    check_ajax_referer('hai-admin-nonce', 'nonce');

    if (!current_user_can('manage_options')) {
      wp_send_json_error(array(
        'message' => __('You do not have permission to perform this action.', 'hai-support')
      ));
    }

    $conversation_ids = $_POST['conversation_id'] ?? array();

    // Convert single ID to array for consistency
    if (!is_array($conversation_ids)) {
      $conversation_ids = array($conversation_ids);
    }

    // Sanitize IDs
    $conversation_ids = array_map('intval', $conversation_ids);
    $conversation_ids = array_filter($conversation_ids);

    if (empty($conversation_ids)) {
      wp_send_json_error(array(
        'message' => __('No valid conversation IDs provided.', 'hai-support')
      ));
    }

    $success = true;
    foreach ($conversation_ids as $id) {
      if (!$this->db->delete_conversation($id)) {
        $success = false;
      }
    }

    if ($success) {
      wp_send_json_success(array(
        'message' => __('Conversations deleted successfully.', 'hai-support')
      ));
    } else {
      wp_send_json_error(array(
        'message' => __('Failed to delete some conversations.', 'hai-support')
      ));
    }
  }

  public function get_conversation()
  {
    check_ajax_referer('hai-admin-nonce', 'nonce');

    if (!current_user_can('manage_options')) {
      wp_send_json_error(array(
        'message' => __('You do not have permission to perform this action.', 'hai-support')
      ));
    }

    $conversation_id = intval($_POST['conversation_id'] ?? 0);

    if (empty($conversation_id)) {
      wp_send_json_error(array(
        'message' => __('Invalid conversation ID.', 'hai-support')
      ));
    }

    $conversation = $this->db->get_conversation($conversation_id);
    if (!$conversation) {
      wp_send_json_error(array(
        'message' => __('Conversation not found.', 'hai-support')
      ));
    }

    // Mark as read if unread
    if ($conversation->status === 'unread') {
      $this->db->update_conversation($conversation_id, array(
        'status' => 'read'
      ));
    }

    // Parse the conversation messages
    $messages = json_decode($conversation->conversation, true);
    if (json_last_error() !== JSON_ERROR_NONE) {
      $messages = array();
    }

    // Format the response data
    $response_data = array(
      'id' => $conversation->id,
      'user_name' => $conversation->user_name,
      'user_ip' => $conversation->user_ip,
      'user_agent' => $conversation->user_agent,
      'location' => $conversation->user_location,
      'status' => $conversation->status,
      'created_at' => mysql2date(get_option('date_format') . ' ' . get_option('time_format'), $conversation->created_at),
      'messages' => is_array($messages) ? $messages : array()
    );

    wp_send_json_success($response_data);
  }

  public function render_dashboard()
  {
    if (!current_user_can('manage_options')) {
      return;
    }

    $conversations = $this->db->get_conversations();
    require_once HAI_SUPPORT_PLUGIN_DIR . 'templates/dashboard.php';
  }

  public function render_settings()
  {
    if (!current_user_can('manage_options')) {
      return;
    }

    require_once HAI_SUPPORT_PLUGIN_DIR . 'templates/settings.php';
  }
}
