<?php
if (!defined('ABSPATH')) {
  exit;
}

class Hai_API
{
  private $api_key;
  private $model;
  private $custom_prompt;
  private $rate_limit_key = 'hai_api_rate_limit';
  private $ip_rate_limit_key = 'hai_ip_rate_limit';
  private $max_requests_per_minute = 60; // Global limit
  private $max_requests_per_ip = 20; // Per IP limit
  private $rate_limit_window = 60; // 1 minute window

  public function __construct()
  {
    $this->api_key = hai_get_setting('hai_openai_api_key');
    $this->model = hai_get_setting('hai_ai_model');
    $this->custom_prompt = hai_get_setting('hai_custom_prompt');
  }

  private function get_client_ip()
  {
    $ip_headers = array(
      'HTTP_CLIENT_IP',
      'HTTP_X_FORWARDED_FOR',
      'HTTP_X_FORWARDED',
      'HTTP_X_CLUSTER_CLIENT_IP',
      'HTTP_FORWARDED_FOR',
      'HTTP_FORWARDED',
      'REMOTE_ADDR'
    );

    foreach ($ip_headers as $header) {
      if (!empty($_SERVER[$header])) {
        $ips = explode(',', $_SERVER[$header]);
        return trim($ips[0]);
      }
    }

    return '';
  }

  private function check_rate_limit()
  {
    // Global rate limit check
    $rate_limit = get_transient($this->rate_limit_key);
    if (false === $rate_limit) {
      $rate_limit = array(
        'count' => 0,
        'timestamp' => time()
      );
    }

    // Reset counter if window has passed
    if (time() - $rate_limit['timestamp'] >= $this->rate_limit_window) {
      $rate_limit = array(
        'count' => 0,
        'timestamp' => time()
      );
    }

    // Check if global limit exceeded
    if ($rate_limit['count'] >= $this->max_requests_per_minute) {
      return new WP_Error(
        'rate_limit_exceeded',
        sprintf(
          __('Global rate limit exceeded. Please try again in %d seconds.', 'hai-support'),
          $this->rate_limit_window - (time() - $rate_limit['timestamp'])
        )
      );
    }

    // IP-based rate limit check
    $ip = $this->get_client_ip();
    if ($ip) {
      $ip_key = $this->ip_rate_limit_key . '_' . md5($ip);
      $ip_limit = get_transient($ip_key);

      if (false === $ip_limit) {
        $ip_limit = array(
          'count' => 0,
          'timestamp' => time()
        );
      }

      // Reset IP counter if window has passed
      if (time() - $ip_limit['timestamp'] >= $this->rate_limit_window) {
        $ip_limit = array(
          'count' => 0,
          'timestamp' => time()
        );
      }

      // Check if IP limit exceeded
      if ($ip_limit['count'] >= $this->max_requests_per_ip) {
        return new WP_Error(
          'ip_rate_limit_exceeded',
          sprintf(
            __('You have exceeded the maximum number of requests. Please try again in %d seconds.', 'hai-support'),
            $this->rate_limit_window - (time() - $ip_limit['timestamp'])
          )
        );
      }

      // Increment IP counter
      $ip_limit['count']++;
      set_transient($ip_key, $ip_limit, $this->rate_limit_window);
    }

    // Increment global counter
    $rate_limit['count']++;
    set_transient($this->rate_limit_key, $rate_limit, $this->rate_limit_window);

    return true;
  }

  public function get_rate_limit_status()
  {
    $global_limit = get_transient($this->rate_limit_key);
    $ip_limit = get_transient($this->ip_rate_limit_key . '_' . md5($this->get_client_ip()));

    return array(
      'global' => array(
        'remaining' => $this->max_requests_per_minute - ($global_limit['count'] ?? 0),
        'reset' => ($global_limit['timestamp'] ?? time()) + $this->rate_limit_window - time()
      ),
      'ip' => array(
        'remaining' => $this->max_requests_per_ip - ($ip_limit['count'] ?? 0),
        'reset' => ($ip_limit['timestamp'] ?? time()) + $this->rate_limit_window - time()
      )
    );
  }

  public function send_message($message, $conversation_history = array())
  {
    if (empty($this->api_key)) {
      return new WP_Error('no_api_key', __('OpenAI API key is not configured.', 'hai-support'));
    }

    // Check rate limit
    $rate_check = $this->check_rate_limit();
    if (is_wp_error($rate_check)) {
      return $rate_check;
    }

    $messages = array();

    // Get site context if available
    $site_context = get_option('hai_site_context', array());

    // Build system message with context
    $system_message = $this->custom_prompt;
    if (!empty($site_context)) {
      $system_message .= "\n\nWebsite Context:\n" . $site_context['summary'];
      if (!empty($site_context['topics'])) {
        $system_message .= "\n\nYou are knowledgeable about:\n- " . implode("\n- ", $site_context['topics']);
      }
    }

    // System message with custom prompt and context
    $messages[] = array(
      'role' => 'system',
      'content' => $system_message
    );

    // Add conversation history
    foreach ($conversation_history as $msg) {
      $messages[] = array(
        'role' => $msg['role'],
        'content' => $msg['content']
      );
    }

    // Add current message
    $messages[] = array(
      'role' => 'user',
      'content' => $message
    );

    $response = wp_remote_post('https://api.openai.com/v1/chat/completions', array(
      'headers' => array(
        'Authorization' => 'Bearer ' . $this->api_key,
        'Content-Type' => 'application/json'
      ),
      'body' => wp_json_encode(array(
        'model' => $this->model,
        'messages' => $messages,
        'temperature' => 0.7,
        'max_tokens' => 1000
      )),
      'timeout' => 30
    ));

    if (is_wp_error($response)) {
      return $response;
    }

    $body = json_decode(wp_remote_retrieve_body($response), true);

    if (isset($body['error'])) {
      return new WP_Error(
        'api_error',
        $body['error']['message'] ?? __('Unknown API error', 'hai-support')
      );
    }

    if (empty($body['choices'][0]['message']['content'])) {
      return new WP_Error(
        'empty_response',
        __('Empty response from API', 'hai-support')
      );
    }

    return array(
      'role' => 'assistant',
      'content' => $body['choices'][0]['message']['content']
    );
  }

  public function validate_api_key($api_key)
  {
    $response = wp_remote_post('https://api.openai.com/v1/chat/completions', array(
      'headers' => array(
        'Authorization' => 'Bearer ' . $api_key,
        'Content-Type' => 'application/json'
      ),
      'body' => wp_json_encode(array(
        'model' => 'gpt-4',
        'messages' => array(
          array(
            'role' => 'user',
            'content' => 'Test'
          )
        ),
        'max_tokens' => 5
      )),
      'timeout' => 10
    ));

    if (is_wp_error($response)) {
      return false;
    }

    $body = json_decode(wp_remote_retrieve_body($response), true);
    return !isset($body['error']);
  }
}
