<?php
if (!defined('ABSPATH')) {
  exit;
}

class Hai_Chat
{
  private $db;
  private $api;
  private $cache_group = 'hai_chat_cache';
  private $cache_expiration = 3600; // 1 hour

  public function __construct()
  {
    $this->db = new Hai_DB();
    $this->api = new Hai_API();

    // Register cache group
    wp_cache_add_non_persistent_groups($this->cache_group);

    add_action('wp_ajax_hai_send_message', array($this, 'handle_message'));
    add_action('wp_ajax_nopriv_hai_send_message', array($this, 'handle_message'));
  }

  private function get_cache_key($message, $conversation_history)
  {
    // Create a unique cache key based on the message and last 3 messages of history
    $last_messages = array_slice($conversation_history, -3);
    return md5($message . serialize($last_messages));
  }

  private function get_cached_response($message, $conversation_history)
  {
    $cache_key = $this->get_cache_key($message, $conversation_history);
    return wp_cache_get($cache_key, $this->cache_group);
  }

  private function cache_response($message, $conversation_history, $response)
  {
    $cache_key = $this->get_cache_key($message, $conversation_history);
    wp_cache_set($cache_key, $response, $this->cache_group, $this->cache_expiration);
  }

  public function handle_message()
  {
    check_ajax_referer('hai-chat-nonce', 'nonce');

    $message = sanitize_textarea_field($_POST['message'] ?? '');
    $session_id = sanitize_text_field($_POST['session_id'] ?? '');
    $current_time = current_time('mysql');

    if (empty($message)) {
      wp_send_json_error(array(
        'message' => __('Message cannot be empty.', 'hai-support')
      ));
    }

    // Get rate limit status before processing
    $rate_limits = $this->api->get_rate_limit_status();

    // Get or create conversation
    $conversation = $this->get_or_create_conversation($session_id);
    if (is_wp_error($conversation)) {
      wp_send_json_error(array(
        'message' => $conversation->get_error_message(),
        'rate_limits' => $rate_limits
      ));
    }

    // Get conversation history
    $history = json_decode($conversation->conversation, true) ?: array();

    // Add user message to history
    $history[] = array(
      'role' => 'user',
      'content' => $message,
      'timestamp' => $current_time
    );

    // Check cache first
    $cached_response = $this->get_cached_response($message, $history);
    if ($cached_response !== false) {
      // Add cached response to history
      $history[] = array(
        'role' => 'assistant',
        'content' => $cached_response,
        'timestamp' => $current_time,
        'cached' => true
      );

      // Update conversation in database
      $this->db->update_conversation($conversation->id, array(
        'conversation' => wp_json_encode($history),
        'updated_at' => $current_time
      ));

      wp_send_json_success(array(
        'message' => $cached_response,
        'session_id' => $conversation->session_id,
        'cached' => true,
        'rate_limits' => $rate_limits
      ));
      return;
    }

    // Get AI response
    $response = $this->api->send_message($message, $history);
    if (is_wp_error($response)) {
      wp_send_json_error(array(
        'message' => $response->get_error_message(),
        'rate_limits' => $rate_limits
      ));
      return;
    }

    // Get updated rate limits after API call
    $updated_rate_limits = $this->api->get_rate_limit_status();

    // Cache the successful response
    $this->cache_response($message, $history, $response['content']);

    // Add AI response to history
    $history[] = array(
      'role' => $response['role'],
      'content' => $response['content'],
      'timestamp' => $current_time
    );

    // Update conversation in database
    $this->db->update_conversation($conversation->id, array(
      'conversation' => wp_json_encode($history),
      'updated_at' => $current_time
    ));

    wp_send_json_success(array(
      'message' => $response['content'],
      'session_id' => $conversation->session_id,
      'rate_limits' => $updated_rate_limits
    ));
  }

  private function get_or_create_conversation($session_id)
  {
    if (empty($session_id)) {
      $session_id = wp_generate_uuid4();
    }

    $conversations = $this->db->get_conversations(array(
      'session_id' => $session_id,
      'limit' => 1
    ));

    if (!empty($conversations)) {
      return $conversations[0];
    }

    // Get user information if logged in
    $user_name = 'Anonymous';
    if (is_user_logged_in()) {
      $current_user = wp_get_current_user();
      $user_name = $current_user->display_name;
      if (empty(trim($user_name))) {
        // Fallback to user login if display name is empty
        $user_name = $current_user->user_login;
      }
    }

    // Create new conversation
    $data = array(
      'session_id' => $session_id,
      'user_name' => $user_name,
      'user_ip' => $this->get_client_ip(),
      'user_agent' => $_SERVER['HTTP_USER_AGENT'] ?? null,
      'user_location' => $this->get_user_location(),
      'conversation' => '[]',
      'status' => 'unread',
      'created_at' => current_time('mysql'),
      'updated_at' => current_time('mysql')
    );

    $result = $this->db->insert_conversation($data);
    if (!$result) {
      return new WP_Error(
        'db_error',
        __('Failed to create conversation.', 'hai-support')
      );
    }

    // Get the newly created conversation
    $conversations = $this->db->get_conversations(array(
      'session_id' => $session_id,
      'limit' => 1
    ));

    if (empty($conversations)) {
      return new WP_Error(
        'db_error',
        __('Failed to retrieve conversation.', 'hai-support')
      );
    }

    return $conversations[0];
  }

  private function get_client_ip()
  {
    $ip_headers = array(
      'HTTP_CLIENT_IP',
      'HTTP_X_FORWARDED_FOR',
      'HTTP_X_FORWARDED',
      'HTTP_X_CLUSTER_CLIENT_IP',
      'HTTP_FORWARDED_FOR',
      'HTTP_FORWARDED',
      'REMOTE_ADDR'
    );

    foreach ($ip_headers as $header) {
      if (!empty($_SERVER[$header])) {
        $ips = explode(',', $_SERVER[$header]);
        return trim($ips[0]);
      }
    }

    return '';
  }

  private function get_user_location()
  {
    $ip = $this->get_client_ip();
    if (empty($ip)) {
      return null;
    }

    $location = hai_get_location_data($ip);
    return !empty($location) ? wp_json_encode($location) : null;
  }
}
